pub struct DaemonServeArgs {
pub empty_poll_ms: u64,
pub wait_poll_ms: u64,
pub notify_when_unblocked: bool,
}Fields
empty_poll_ms: u64Poll interval in milliseconds while waiting for new tasks when queue is empty (default: 30000, min: 50).
wait_poll_ms: u64Poll interval in milliseconds while waiting for blocked tasks (default: 1000, min: 50).
notify_when_unblocked: boolNotify when queue becomes unblocked (desktop + webhook).