pub struct QueueIssuePublishManyArgs {
pub status: Vec<StatusArg>,
pub tag: Vec<String>,
pub id_pattern: Option<String>,
pub dry_run: bool,
pub execute: bool,
pub label: Vec<String>,
pub assignee: Vec<String>,
pub repo: Option<String>,
}Expand description
Arguments for ralph queue issue publish-many.
Fields
status: Vec<StatusArg>Filter by status (repeatable). Defaults to all non-draft statuses.
tag: Vec<String>Filter by tag (repeatable).
id_pattern: Option<String>Filter by task ID regular expression.
dry_run: boolPreview mode (default). No writes to queue or GitHub.
execute: boolExecute publishes and persist GitHub metadata.
label: Vec<String>Labels to apply for each issue in the bulk run.
assignee: Vec<String>Assignees to apply for each issue in the bulk run.
repo: Option<String>Target repository (OWNER/REPO format). Optional; uses current repo by default.