pub struct QueuePruneArgs {
pub age: Option<u32>,
pub status: Vec<StatusArg>,
pub keep_last: Option<u32>,
pub dry_run: bool,
}Expand description
Arguments for ralph queue prune.
Fields
age: Option<u32>Only prune tasks completed at least N days ago.
status: Vec<StatusArg>Filter by task status (repeatable).
keep_last: Option<u32>Keep the N most recently completed tasks regardless of filters.
dry_run: boolShow what would be pruned without writing to disk.