pub enum TaskFromCommand {
Template(TaskFromTemplateArgs),
}Expand description
Subcommands for ralph task from
Variants
Template(TaskFromTemplateArgs)
Build a task from a template with variable substitution.
This is a convenience command that combines template selection, variable substitution, and task creation in one step.