TaskDecomposeArgs

Struct TaskDecomposeArgs 

pub struct TaskDecomposeArgs {
Show 16 fields pub source: Vec<String>, pub attach_to: Option<String>, pub max_depth: u8, pub max_children: u8, pub max_nodes: u16, pub status: TaskStatusArg, pub child_policy: TaskDecomposeChildPolicyArg, pub with_dependencies: bool, pub write: bool, pub preview: bool, pub format: TaskDecomposeFormatArg, pub runner: Option<String>, pub model: Option<String>, pub effort: Option<String>, pub repo_prompt: Option<RepoPromptMode>, pub runner_cli: RunnerCliArgs,
}

Fields

source: Vec<String>

Task ID or freeform request text to decompose. If omitted, reads from stdin.

attach_to: Option<String>

Attach a new decomposition subtree under an existing parent task.

max_depth: u8

Maximum hierarchy depth to generate, including the root node.

max_children: u8

Maximum number of children allowed for any single node.

max_nodes: u16

Maximum total nodes allowed in the generated tree.

status: TaskStatusArg

Status to assign to newly created tasks.

child_policy: TaskDecomposeChildPolicyArg

Child-tree handling when the effective parent already has children.

with_dependencies: bool

Infer sibling dependencies from the planner output.

write: bool

Write the proposed decomposition into the queue.

preview: bool

Explicitly request preview mode.

format: TaskDecomposeFormatArg

Output format.

runner: Option<String>

Runner to use. CLI flag overrides config defaults (project > global > built-in).

model: Option<String>

Model to use. CLI flag overrides config defaults (project > global > built-in).

effort: Option<String>

Codex reasoning effort. CLI flag overrides config defaults (project > global > built-in). Ignored for opencode and gemini.

repo_prompt: Option<RepoPromptMode>

RepoPrompt mode (tools, plan, off). Alias: -rp.

runner_cli: RunnerCliArgs