TaskUpdateArgs

Struct TaskUpdateArgs 

pub struct TaskUpdateArgs {
    pub fields: String,
    pub runner: Option<String>,
    pub model: Option<String>,
    pub effort: Option<String>,
    pub repo_prompt: Option<RepoPromptMode>,
    pub runner_cli: RunnerCliArgs,
    pub task_id: Option<String>,
    pub dry_run: bool,
}

Fields

fields: String

Fields to update (comma-separated, default: all).

Valid fields: scope, evidence, plan, notes, tags, depends_on

runner: Option<String>

Runner to use. CLI flag overrides config defaults (project > global > built-in).

model: Option<String>

Model to use. CLI flag overrides config defaults (project > global > built-in).

effort: Option<String>

Codex reasoning effort. CLI flag overrides config defaults (project > global > built-in). Ignored for opencode and gemini.

repo_prompt: Option<RepoPromptMode>

RepoPrompt mode (tools, plan, off). Alias: -rp.

runner_cli: RunnerCliArgstask_id: Option<String>

Task ID to update (omit to update all tasks).

dry_run: bool

Preview changes without modifying the queue.

For task update, this shows the prompt that would be sent to the runner. Actual changes depend on runner analysis of repository state.