pub fn handle_version(args: VersionArgs) -> Result<()>Expand description
Display version information for Ralph CLI.
Prints the package version by default. With –verbose, also displays git commit hash and build timestamp when available.
pub fn handle_version(args: VersionArgs) -> Result<()>Display version information for Ralph CLI.
Prints the package version by default. With –verbose, also displays git commit hash and build timestamp when available.