Module webhook

Module webhook 

Webhook CLI commands.

Responsibilities:

  • Provide ralph webhook test command for testing webhook configuration.
  • Provide ralph webhook status for diagnostics snapshots.
  • Provide ralph webhook replay for explicit bounded failure replay.

Does NOT handle:

  • Webhook configuration management (use config files).
  • Direct HTTP delivery internals (delegated to crate::webhook).

Structs

ReplayArgs
StatusArgs
TestArgs
WebhookArgs

Enums

WebhookCommand
WebhookStatusFormat

Functions

handle_webhook