RunLoopOptions

Struct RunLoopOptions 

pub struct RunLoopOptions {
Show 13 fields pub max_tasks: u32, pub agent_overrides: AgentOverrides, pub force: bool, pub auto_resume: bool, pub starting_completed: u32, pub non_interactive: bool, pub parallel_workers: Option<u8>, pub wait_when_blocked: bool, pub wait_poll_ms: u64, pub wait_timeout_seconds: u64, pub notify_when_unblocked: bool, pub wait_when_empty: bool, pub empty_poll_ms: u64,
}

Fields

max_tasks: u32

0 means “no limit”

agent_overrides: AgentOverridesforce: boolauto_resume: bool

Auto-resume without prompting (for –resume flag)

starting_completed: u32

Starting completed count (for resumed sessions)

non_interactive: bool

Skip interactive prompts (for CI/non-interactive runs)

parallel_workers: Option<u8>

Number of parallel workers to use when parallel mode is enabled.

wait_when_blocked: bool

Wait when blocked by dependencies/schedule instead of exiting.

wait_poll_ms: u64

Poll interval in milliseconds while waiting (default: 1000).

wait_timeout_seconds: u64

Timeout in seconds for waiting (0 = no timeout).

notify_when_unblocked: bool

Notify when queue becomes unblocked.

wait_when_empty: bool

Wait when queue is empty instead of exiting (continuous mode).

empty_poll_ms: u64

Poll interval in milliseconds while waiting on an empty queue (default: 30000).