pub fn check_runner_binary(bin: &str) -> BinaryStatusExpand description
Check if a runner binary is installed by trying common version/help flags.
Tries the following in order: –version, -V, –help, help
pub fn check_runner_binary(bin: &str) -> BinaryStatusCheck if a runner binary is installed by trying common version/help flags.
Tries the following in order: –version, -V, –help, help