pub fn apply_layer(base: Config, layer: ConfigLayer) -> Result<Config>Expand description
Apply a config layer on top of a base config. Later layers override earlier ones using leaf-wise merge semantics.
pub fn apply_layer(base: Config, layer: ConfigLayer) -> Result<Config>Apply a config layer on top of a base config. Later layers override earlier ones using leaf-wise merge semantics.