pub struct MachineConfigResolveDocument {
pub version: u32,
pub paths: MachineQueuePaths,
pub safety: MachineConfigSafetySummary,
pub config: Config,
pub resume_preview: Option<MachineResumeDecision>,
}Fields
version: u32paths: MachineQueuePathssafety: MachineConfigSafetySummaryconfig: Configresume_preview: Option<MachineResumeDecision>Trait Implementations
Sourceimpl Clone for MachineConfigResolveDocument
impl Clone for MachineConfigResolveDocument
Sourcefn clone(&self) -> MachineConfigResolveDocument
fn clone(&self) -> MachineConfigResolveDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineConfigResolveDocument
impl Debug for MachineConfigResolveDocument
Sourceimpl<'de> Deserialize<'de> for MachineConfigResolveDocument
impl<'de> Deserialize<'de> for MachineConfigResolveDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineConfigResolveDocument
impl JsonSchema for MachineConfigResolveDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineConfigResolveDocument
impl RefUnwindSafe for MachineConfigResolveDocument
impl Send for MachineConfigResolveDocument
impl Sync for MachineConfigResolveDocument
impl Unpin for MachineConfigResolveDocument
impl UnsafeUnpin for MachineConfigResolveDocument
impl UnwindSafe for MachineConfigResolveDocument