pub struct MachineConfigSafetySummary {
pub repo_trusted: bool,
pub dirty_repo: bool,
pub git_publish_mode: GitPublishMode,
pub approval_mode: Option<RunnerApprovalMode>,
pub ci_gate_enabled: bool,
pub git_revert_mode: GitRevertMode,
pub parallel_configured: bool,
pub execution_interactivity: String,
pub interactive_approval_supported: bool,
}Fields
repo_trusted: booldirty_repo: boolgit_publish_mode: GitPublishModeapproval_mode: Option<RunnerApprovalMode>ci_gate_enabled: boolgit_revert_mode: GitRevertModeparallel_configured: boolexecution_interactivity: Stringinteractive_approval_supported: boolTrait Implementations
Sourceimpl Clone for MachineConfigSafetySummary
impl Clone for MachineConfigSafetySummary
Sourcefn clone(&self) -> MachineConfigSafetySummary
fn clone(&self) -> MachineConfigSafetySummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineConfigSafetySummary
impl Debug for MachineConfigSafetySummary
Sourceimpl<'de> Deserialize<'de> for MachineConfigSafetySummary
impl<'de> Deserialize<'de> for MachineConfigSafetySummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineConfigSafetySummary
impl JsonSchema for MachineConfigSafetySummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineConfigSafetySummary
impl RefUnwindSafe for MachineConfigSafetySummary
impl Send for MachineConfigSafetySummary
impl Sync for MachineConfigSafetySummary
impl Unpin for MachineConfigSafetySummary
impl UnsafeUnpin for MachineConfigSafetySummary
impl UnwindSafe for MachineConfigSafetySummary