pub struct MachineContinuationAction {
pub title: String,
pub command: String,
pub detail: String,
}Fields
title: Stringcommand: Stringdetail: StringTrait Implementations
Sourceimpl Clone for MachineContinuationAction
impl Clone for MachineContinuationAction
Sourcefn clone(&self) -> MachineContinuationAction
fn clone(&self) -> MachineContinuationAction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineContinuationAction
impl Debug for MachineContinuationAction
Sourceimpl<'de> Deserialize<'de> for MachineContinuationAction
impl<'de> Deserialize<'de> for MachineContinuationAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineContinuationAction
impl JsonSchema for MachineContinuationAction
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineContinuationAction
impl RefUnwindSafe for MachineContinuationAction
impl Send for MachineContinuationAction
impl Sync for MachineContinuationAction
impl Unpin for MachineContinuationAction
impl UnsafeUnpin for MachineContinuationAction
impl UnwindSafe for MachineContinuationAction