pub struct MachineContinuationSummary {
pub headline: String,
pub detail: String,
pub blocking: Option<BlockingState>,
pub next_steps: Vec<MachineContinuationAction>,
}Fields
headline: Stringdetail: Stringblocking: Option<BlockingState>next_steps: Vec<MachineContinuationAction>Trait Implementations
Sourceimpl Clone for MachineContinuationSummary
impl Clone for MachineContinuationSummary
Sourcefn clone(&self) -> MachineContinuationSummary
fn clone(&self) -> MachineContinuationSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineContinuationSummary
impl Debug for MachineContinuationSummary
Sourceimpl<'de> Deserialize<'de> for MachineContinuationSummary
impl<'de> Deserialize<'de> for MachineContinuationSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineContinuationSummary
impl JsonSchema for MachineContinuationSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineContinuationSummary
impl RefUnwindSafe for MachineContinuationSummary
impl Send for MachineContinuationSummary
impl Sync for MachineContinuationSummary
impl Unpin for MachineContinuationSummary
impl UnsafeUnpin for MachineContinuationSummary
impl UnwindSafe for MachineContinuationSummary