pub struct MachineDecomposeDocument {
pub version: u32,
pub blocking: Option<BlockingState>,
pub result: Value,
pub continuation: MachineContinuationSummary,
}Fields
version: u32blocking: Option<BlockingState>result: Valuecontinuation: MachineContinuationSummaryTrait Implementations
Sourceimpl Clone for MachineDecomposeDocument
impl Clone for MachineDecomposeDocument
Sourcefn clone(&self) -> MachineDecomposeDocument
fn clone(&self) -> MachineDecomposeDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineDecomposeDocument
impl Debug for MachineDecomposeDocument
Sourceimpl<'de> Deserialize<'de> for MachineDecomposeDocument
impl<'de> Deserialize<'de> for MachineDecomposeDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineDecomposeDocument
impl JsonSchema for MachineDecomposeDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineDecomposeDocument
impl RefUnwindSafe for MachineDecomposeDocument
impl Send for MachineDecomposeDocument
impl Sync for MachineDecomposeDocument
impl Unpin for MachineDecomposeDocument
impl UnsafeUnpin for MachineDecomposeDocument
impl UnwindSafe for MachineDecomposeDocument