pub struct MachineDoctorReportDocument {
pub version: u32,
pub blocking: Option<BlockingState>,
pub report: Value,
}Fields
version: u32blocking: Option<BlockingState>report: ValueTrait Implementations
Sourceimpl Clone for MachineDoctorReportDocument
impl Clone for MachineDoctorReportDocument
Sourcefn clone(&self) -> MachineDoctorReportDocument
fn clone(&self) -> MachineDoctorReportDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineDoctorReportDocument
impl Debug for MachineDoctorReportDocument
Sourceimpl<'de> Deserialize<'de> for MachineDoctorReportDocument
impl<'de> Deserialize<'de> for MachineDoctorReportDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineDoctorReportDocument
impl JsonSchema for MachineDoctorReportDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineDoctorReportDocument
impl RefUnwindSafe for MachineDoctorReportDocument
impl Send for MachineDoctorReportDocument
impl Sync for MachineDoctorReportDocument
impl Unpin for MachineDoctorReportDocument
impl UnsafeUnpin for MachineDoctorReportDocument
impl UnwindSafe for MachineDoctorReportDocument