pub struct MachineErrorDocument {
pub version: u32,
pub code: MachineErrorCode,
pub message: String,
pub detail: Option<String>,
pub retryable: bool,
}Fields
version: u32code: MachineErrorCodemessage: Stringdetail: Option<String>retryable: boolTrait Implementations
Sourceimpl Clone for MachineErrorDocument
impl Clone for MachineErrorDocument
Sourcefn clone(&self) -> MachineErrorDocument
fn clone(&self) -> MachineErrorDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineErrorDocument
impl Debug for MachineErrorDocument
Sourceimpl<'de> Deserialize<'de> for MachineErrorDocument
impl<'de> Deserialize<'de> for MachineErrorDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineErrorDocument
impl JsonSchema for MachineErrorDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineErrorDocument
impl RefUnwindSafe for MachineErrorDocument
impl Send for MachineErrorDocument
impl Sync for MachineErrorDocument
impl Unpin for MachineErrorDocument
impl UnsafeUnpin for MachineErrorDocument
impl UnwindSafe for MachineErrorDocument