pub struct MachineParallelLifecycleCounts {
pub running: u32,
pub integrating: u32,
pub completed: u32,
pub failed: u32,
pub blocked: u32,
pub total: u32,
}Expand description
Worker counts by lifecycle for machine run parallel-status (document v3+).
Fields
running: u32integrating: u32completed: u32failed: u32blocked: u32total: u32Trait Implementations
Sourceimpl Clone for MachineParallelLifecycleCounts
impl Clone for MachineParallelLifecycleCounts
Sourcefn clone(&self) -> MachineParallelLifecycleCounts
fn clone(&self) -> MachineParallelLifecycleCounts
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for MachineParallelLifecycleCounts
impl<'de> Deserialize<'de> for MachineParallelLifecycleCounts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineParallelLifecycleCounts
impl JsonSchema for MachineParallelLifecycleCounts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MachineParallelLifecycleCounts
impl PartialEq for MachineParallelLifecycleCounts
Sourcefn eq(&self, other: &MachineParallelLifecycleCounts) -> bool
fn eq(&self, other: &MachineParallelLifecycleCounts) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for MachineParallelLifecycleCounts
impl Eq for MachineParallelLifecycleCounts
impl StructuralPartialEq for MachineParallelLifecycleCounts