pub struct MachineParallelStatusDocument {
pub version: u32,
pub blocking: Option<BlockingState>,
pub continuation: MachineContinuationSummary,
pub status: Value,
}Fields
version: u32blocking: Option<BlockingState>continuation: MachineContinuationSummarystatus: ValueTrait Implementations
Sourceimpl Clone for MachineParallelStatusDocument
impl Clone for MachineParallelStatusDocument
Sourcefn clone(&self) -> MachineParallelStatusDocument
fn clone(&self) -> MachineParallelStatusDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for MachineParallelStatusDocument
impl<'de> Deserialize<'de> for MachineParallelStatusDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineParallelStatusDocument
impl JsonSchema for MachineParallelStatusDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineParallelStatusDocument
impl RefUnwindSafe for MachineParallelStatusDocument
impl Send for MachineParallelStatusDocument
impl Sync for MachineParallelStatusDocument
impl Unpin for MachineParallelStatusDocument
impl UnsafeUnpin for MachineParallelStatusDocument
impl UnwindSafe for MachineParallelStatusDocument