pub struct MachineQueuePaths {
pub repo_root: String,
pub queue_path: String,
pub done_path: String,
pub project_config_path: Option<String>,
pub global_config_path: Option<String>,
}Fields
repo_root: Stringqueue_path: Stringdone_path: Stringproject_config_path: Option<String>global_config_path: Option<String>Trait Implementations
Sourceimpl Clone for MachineQueuePaths
impl Clone for MachineQueuePaths
Sourcefn clone(&self) -> MachineQueuePaths
fn clone(&self) -> MachineQueuePaths
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineQueuePaths
impl Debug for MachineQueuePaths
Sourceimpl<'de> Deserialize<'de> for MachineQueuePaths
impl<'de> Deserialize<'de> for MachineQueuePaths
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineQueuePaths
impl JsonSchema for MachineQueuePaths
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineQueuePaths
impl RefUnwindSafe for MachineQueuePaths
impl Send for MachineQueuePaths
impl Sync for MachineQueuePaths
impl Unpin for MachineQueuePaths
impl UnsafeUnpin for MachineQueuePaths
impl UnwindSafe for MachineQueuePaths