pub struct MachineQueueRepairDocument {
pub version: u32,
pub dry_run: bool,
pub changed: bool,
pub blocking: Option<BlockingState>,
pub report: Value,
pub continuation: MachineContinuationSummary,
}Fields
version: u32dry_run: boolchanged: boolblocking: Option<BlockingState>report: Valuecontinuation: MachineContinuationSummaryTrait Implementations
Sourceimpl Clone for MachineQueueRepairDocument
impl Clone for MachineQueueRepairDocument
Sourcefn clone(&self) -> MachineQueueRepairDocument
fn clone(&self) -> MachineQueueRepairDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineQueueRepairDocument
impl Debug for MachineQueueRepairDocument
Sourceimpl<'de> Deserialize<'de> for MachineQueueRepairDocument
impl<'de> Deserialize<'de> for MachineQueueRepairDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineQueueRepairDocument
impl JsonSchema for MachineQueueRepairDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineQueueRepairDocument
impl RefUnwindSafe for MachineQueueRepairDocument
impl Send for MachineQueueRepairDocument
impl Sync for MachineQueueRepairDocument
impl Unpin for MachineQueueRepairDocument
impl UnsafeUnpin for MachineQueueRepairDocument
impl UnwindSafe for MachineQueueRepairDocument