pub struct MachineQueueUndoDocument {
pub version: u32,
pub dry_run: bool,
pub restored: bool,
pub blocking: Option<BlockingState>,
pub result: Option<Value>,
pub continuation: MachineContinuationSummary,
}Fields
version: u32dry_run: boolrestored: boolblocking: Option<BlockingState>result: Option<Value>continuation: MachineContinuationSummaryTrait Implementations
Sourceimpl Clone for MachineQueueUndoDocument
impl Clone for MachineQueueUndoDocument
Sourcefn clone(&self) -> MachineQueueUndoDocument
fn clone(&self) -> MachineQueueUndoDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineQueueUndoDocument
impl Debug for MachineQueueUndoDocument
Sourceimpl<'de> Deserialize<'de> for MachineQueueUndoDocument
impl<'de> Deserialize<'de> for MachineQueueUndoDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineQueueUndoDocument
impl JsonSchema for MachineQueueUndoDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineQueueUndoDocument
impl RefUnwindSafe for MachineQueueUndoDocument
impl Send for MachineQueueUndoDocument
impl Sync for MachineQueueUndoDocument
impl Unpin for MachineQueueUndoDocument
impl UnsafeUnpin for MachineQueueUndoDocument
impl UnwindSafe for MachineQueueUndoDocument