pub struct MachineQueueUnlockInspectDocument {
pub version: u32,
pub condition: MachineQueueUnlockCondition,
pub blocking: Option<BlockingState>,
pub unlock_allowed: bool,
pub continuation: MachineContinuationSummary,
}Fields
version: u32condition: MachineQueueUnlockConditionblocking: Option<BlockingState>unlock_allowed: boolcontinuation: MachineContinuationSummaryTrait Implementations
Sourceimpl Clone for MachineQueueUnlockInspectDocument
impl Clone for MachineQueueUnlockInspectDocument
Sourcefn clone(&self) -> MachineQueueUnlockInspectDocument
fn clone(&self) -> MachineQueueUnlockInspectDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for MachineQueueUnlockInspectDocument
impl<'de> Deserialize<'de> for MachineQueueUnlockInspectDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineQueueUnlockInspectDocument
impl JsonSchema for MachineQueueUnlockInspectDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineQueueUnlockInspectDocument
impl RefUnwindSafe for MachineQueueUnlockInspectDocument
impl Send for MachineQueueUnlockInspectDocument
impl Sync for MachineQueueUnlockInspectDocument
impl Unpin for MachineQueueUnlockInspectDocument
impl UnsafeUnpin for MachineQueueUnlockInspectDocument
impl UnwindSafe for MachineQueueUnlockInspectDocument