pub struct MachineQueueValidateDocument {
pub version: u32,
pub valid: bool,
pub blocking: Option<BlockingState>,
pub warnings: Vec<MachineValidationWarning>,
pub continuation: MachineContinuationSummary,
}Fields
version: u32valid: boolblocking: Option<BlockingState>warnings: Vec<MachineValidationWarning>continuation: MachineContinuationSummaryTrait Implementations
Sourceimpl Clone for MachineQueueValidateDocument
impl Clone for MachineQueueValidateDocument
Sourcefn clone(&self) -> MachineQueueValidateDocument
fn clone(&self) -> MachineQueueValidateDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineQueueValidateDocument
impl Debug for MachineQueueValidateDocument
Sourceimpl<'de> Deserialize<'de> for MachineQueueValidateDocument
impl<'de> Deserialize<'de> for MachineQueueValidateDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineQueueValidateDocument
impl JsonSchema for MachineQueueValidateDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineQueueValidateDocument
impl RefUnwindSafe for MachineQueueValidateDocument
impl Send for MachineQueueValidateDocument
impl Sync for MachineQueueValidateDocument
impl Unpin for MachineQueueValidateDocument
impl UnsafeUnpin for MachineQueueValidateDocument
impl UnwindSafe for MachineQueueValidateDocument