pub struct MachineResumeDecision {
pub status: String,
pub scope: String,
pub reason: String,
pub task_id: Option<String>,
pub message: String,
pub detail: String,
}Fields
status: Stringscope: Stringreason: Stringtask_id: Option<String>message: Stringdetail: StringTrait Implementations
Sourceimpl Clone for MachineResumeDecision
impl Clone for MachineResumeDecision
Sourcefn clone(&self) -> MachineResumeDecision
fn clone(&self) -> MachineResumeDecision
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineResumeDecision
impl Debug for MachineResumeDecision
Sourceimpl<'de> Deserialize<'de> for MachineResumeDecision
impl<'de> Deserialize<'de> for MachineResumeDecision
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineResumeDecision
impl JsonSchema for MachineResumeDecision
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineResumeDecision
impl RefUnwindSafe for MachineResumeDecision
impl Send for MachineResumeDecision
impl Sync for MachineResumeDecision
impl Unpin for MachineResumeDecision
impl UnsafeUnpin for MachineResumeDecision
impl UnwindSafe for MachineResumeDecision