pub struct MachineRunEventEnvelope {
pub version: u32,
pub kind: MachineRunEventKind,
pub timestamp: String,
pub run_mode: Option<String>,
pub task_id: Option<String>,
pub phase: Option<String>,
pub exit_code: Option<i32>,
pub message: Option<String>,
pub stream: Option<String>,
pub payload: Option<Value>,
}Fields
version: u32kind: MachineRunEventKindtimestamp: Stringrun_mode: Option<String>task_id: Option<String>phase: Option<String>exit_code: Option<i32>message: Option<String>stream: Option<String>payload: Option<Value>Trait Implementations
Sourceimpl Clone for MachineRunEventEnvelope
impl Clone for MachineRunEventEnvelope
Sourcefn clone(&self) -> MachineRunEventEnvelope
fn clone(&self) -> MachineRunEventEnvelope
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineRunEventEnvelope
impl Debug for MachineRunEventEnvelope
Sourceimpl<'de> Deserialize<'de> for MachineRunEventEnvelope
impl<'de> Deserialize<'de> for MachineRunEventEnvelope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineRunEventEnvelope
impl JsonSchema for MachineRunEventEnvelope
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineRunEventEnvelope
impl RefUnwindSafe for MachineRunEventEnvelope
impl Send for MachineRunEventEnvelope
impl Sync for MachineRunEventEnvelope
impl Unpin for MachineRunEventEnvelope
impl UnsafeUnpin for MachineRunEventEnvelope
impl UnwindSafe for MachineRunEventEnvelope