pub struct MachineRunSummaryDocument {
pub version: u32,
pub task_id: Option<String>,
pub exit_code: i32,
pub outcome: String,
pub blocking: Option<BlockingState>,
}Fields
version: u32task_id: Option<String>exit_code: i32outcome: Stringblocking: Option<BlockingState>Trait Implementations
Sourceimpl Clone for MachineRunSummaryDocument
impl Clone for MachineRunSummaryDocument
Sourcefn clone(&self) -> MachineRunSummaryDocument
fn clone(&self) -> MachineRunSummaryDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineRunSummaryDocument
impl Debug for MachineRunSummaryDocument
Sourceimpl<'de> Deserialize<'de> for MachineRunSummaryDocument
impl<'de> Deserialize<'de> for MachineRunSummaryDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineRunSummaryDocument
impl JsonSchema for MachineRunSummaryDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineRunSummaryDocument
impl RefUnwindSafe for MachineRunSummaryDocument
impl Send for MachineRunSummaryDocument
impl Sync for MachineRunSummaryDocument
impl Unpin for MachineRunSummaryDocument
impl UnsafeUnpin for MachineRunSummaryDocument
impl UnwindSafe for MachineRunSummaryDocument