pub struct MachineSystemInfoDocument {
pub version: u32,
pub cli_version: String,
}Fields
version: u32cli_version: StringTrait Implementations
Sourceimpl Clone for MachineSystemInfoDocument
impl Clone for MachineSystemInfoDocument
Sourcefn clone(&self) -> MachineSystemInfoDocument
fn clone(&self) -> MachineSystemInfoDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineSystemInfoDocument
impl Debug for MachineSystemInfoDocument
Sourceimpl<'de> Deserialize<'de> for MachineSystemInfoDocument
impl<'de> Deserialize<'de> for MachineSystemInfoDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineSystemInfoDocument
impl JsonSchema for MachineSystemInfoDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineSystemInfoDocument
impl RefUnwindSafe for MachineSystemInfoDocument
impl Send for MachineSystemInfoDocument
impl Sync for MachineSystemInfoDocument
impl Unpin for MachineSystemInfoDocument
impl UnsafeUnpin for MachineSystemInfoDocument
impl UnwindSafe for MachineSystemInfoDocument