pub struct MachineTaskMutationDocument {
pub version: u32,
pub blocking: Option<BlockingState>,
pub report: Value,
pub continuation: MachineContinuationSummary,
}Fields
version: u32blocking: Option<BlockingState>report: Valuecontinuation: MachineContinuationSummaryTrait Implementations
Sourceimpl Clone for MachineTaskMutationDocument
impl Clone for MachineTaskMutationDocument
Sourcefn clone(&self) -> MachineTaskMutationDocument
fn clone(&self) -> MachineTaskMutationDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MachineTaskMutationDocument
impl Debug for MachineTaskMutationDocument
Sourceimpl<'de> Deserialize<'de> for MachineTaskMutationDocument
impl<'de> Deserialize<'de> for MachineTaskMutationDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineTaskMutationDocument
impl JsonSchema for MachineTaskMutationDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineTaskMutationDocument
impl RefUnwindSafe for MachineTaskMutationDocument
impl Send for MachineTaskMutationDocument
impl Sync for MachineTaskMutationDocument
impl Unpin for MachineTaskMutationDocument
impl UnsafeUnpin for MachineTaskMutationDocument
impl UnwindSafe for MachineTaskMutationDocument