pub struct MachineWorkspaceOverviewDocument {
pub version: u32,
pub queue: MachineQueueReadDocument,
pub config: MachineConfigResolveDocument,
}Fields
version: u32queue: MachineQueueReadDocumentconfig: MachineConfigResolveDocumentTrait Implementations
Sourceimpl Clone for MachineWorkspaceOverviewDocument
impl Clone for MachineWorkspaceOverviewDocument
Sourcefn clone(&self) -> MachineWorkspaceOverviewDocument
fn clone(&self) -> MachineWorkspaceOverviewDocument
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for MachineWorkspaceOverviewDocument
impl<'de> Deserialize<'de> for MachineWorkspaceOverviewDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MachineWorkspaceOverviewDocument
impl JsonSchema for MachineWorkspaceOverviewDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MachineWorkspaceOverviewDocument
impl RefUnwindSafe for MachineWorkspaceOverviewDocument
impl Send for MachineWorkspaceOverviewDocument
impl Sync for MachineWorkspaceOverviewDocument
impl Unpin for MachineWorkspaceOverviewDocument
impl UnsafeUnpin for MachineWorkspaceOverviewDocument
impl UnwindSafe for MachineWorkspaceOverviewDocument