pub struct QueueFile {
pub version: u32,
pub tasks: Vec<Task>,
}Fields
version: u32tasks: Vec<Task>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for QueueFile
impl<'de> Deserialize<'de> for QueueFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QueueFile
impl JsonSchema for QueueFile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for QueueFile
impl RefUnwindSafe for QueueFile
impl Send for QueueFile
impl Sync for QueueFile
impl Unpin for QueueFile
impl UnsafeUnpin for QueueFile
impl UnwindSafe for QueueFile