pub fn is_behind_upstream( repo_root: &Path, branch: &str, ) -> Result<bool, GitError>
Check if the current branch is behind its upstream.
Returns true if the upstream has commits that are not in the current branch.