is_supervising_process

Function is_supervising_process 

pub fn is_supervising_process(lock_dir: &Path) -> Result<bool>
Check if the queue lock is currently held by a supervising process (run one or run loop), which means the caller is running under ralph’s supervision and should not attempt to acquire the lock.