pub struct LspClient { /* private fields */ }Implementations
Sourceimpl LspClient
impl LspClient
pub fn new(language: &str, workspace: &Path) -> Self
pub fn language(&self) -> &str
Sourcepub fn handles_extension(&self, ext: &str) -> bool
pub fn handles_extension(&self, ext: &str) -> bool
Returns true if this client handles files with the given extension.
Sourcepub async fn go_to_definition(
&mut self,
file: &Path,
line: u32,
col: u32,
) -> Result<String>
pub async fn go_to_definition( &mut self, file: &Path, line: u32, col: u32, ) -> Result<String>
Jump to the definition of the symbol at file:line:col (1-based).
Sourcepub async fn find_references(
&mut self,
file: &Path,
line: u32,
col: u32,
) -> Result<String>
pub async fn find_references( &mut self, file: &Path, line: u32, col: u32, ) -> Result<String>
Find all references to the symbol at file:line:col (1-based).