rinfo

Macro rinfo 

macro_rules! rinfo {
    ($($arg:tt)+) => { ... };
}
Macros for logging with immediate redaction. Note: These are mostly redundant if RedactedLogger is used, but provide explicit intent and can be used when the global logger is not wrapped.