pub fn notify_task_failed(
task_id: &str,
task_title: &str,
error: &str,
config: &NotificationConfig,
)Expand description
Send task failure notification. Silently logs errors but never fails the calling operation.
pub fn notify_task_failed(
task_id: &str,
task_title: &str,
error: &str,
config: &NotificationConfig,
)Send task failure notification. Silently logs errors but never fails the calling operation.