pub fn notify_watch_new_task(count: usize, config: &NotificationConfig)Expand description
Send watch mode notification for newly detected tasks. Silently logs errors but never fails the calling operation.
pub fn notify_watch_new_task(count: usize, config: &NotificationConfig)Send watch mode notification for newly detected tasks. Silently logs errors but never fails the calling operation.