pub enum TaskEditKey {
Show 23 variants
Title,
Description,
Status,
Priority,
Tags,
Scope,
Evidence,
Plan,
Notes,
Request,
DependsOn,
Blocks,
RelatesTo,
Duplicates,
CustomFields,
Agent,
CreatedAt,
UpdatedAt,
CompletedAt,
StartedAt,
ScheduledStart,
EstimatedMinutes,
ActualMinutes,
}Variants
Title
Description
Status
Priority
Tags
Scope
Evidence
Plan
Notes
Request
DependsOn
Blocks
RelatesTo
Duplicates
CustomFields
Agent
CreatedAt
UpdatedAt
CompletedAt
StartedAt
ScheduledStart
EstimatedMinutes
ActualMinutes
Implementations
Sourceimpl TaskEditKey
impl TaskEditKey
pub fn as_str(self) -> &'static str
Sourcepub fn is_list_field(self) -> bool
pub fn is_list_field(self) -> bool
Returns whether this field is a list type (Vec<String>).
Sourcepub fn format_value(self, task: &Task, list_sep: &str) -> String
pub fn format_value(self, task: &Task, list_sep: &str) -> String
Format this field’s value from a task with the given list separator.
For list fields, elements are joined with the provided separator. For optional fields, returns empty string when None.