pub struct SizeCheckResult {
pub exceeds_size_threshold: bool,
pub exceeds_count_threshold: bool,
pub info: QueueSizeInfo,
pub size_threshold_kb: u32,
pub count_threshold: u32,
}Expand description
Result of checking queue size against thresholds.
Fields
exceeds_size_threshold: boolWhether the file size exceeds the threshold.
exceeds_count_threshold: boolWhether the task count exceeds the threshold.
info: QueueSizeInfoThe size information that was checked.
size_threshold_kb: u32The size threshold that was used for the check (in KB).
count_threshold: u32The task count threshold that was used for the check.