pub enum OutputStream {
Terminal,
HandlerOnly,
}Expand description
Controls whether runner output is streamed directly to the terminal.
Variants
Terminal
Stream runner output to stdout/stderr as well as any output handler.
HandlerOnly
Suppress direct terminal output and only deliver output to the handler.
Implementations
Sourceimpl OutputStream
impl OutputStream
Sourcepub fn streams_to_terminal(self) -> bool
pub fn streams_to_terminal(self) -> bool
Returns true when output should be streamed to stdout/stderr.