pub struct SanityOptions {
pub auto_fix: bool,
pub skip: bool,
pub non_interactive: bool,
}Expand description
Options for controlling sanity check behavior.
Fields
auto_fix: boolAuto-approve all fixes without prompting.
skip: boolSkip all sanity checks.
non_interactive: boolSkip interactive prompts even if running in a TTY.
Implementations
Sourceimpl SanityOptions
impl SanityOptions
Sourcepub fn can_prompt(&self) -> bool
pub fn can_prompt(&self) -> bool
Check if we can prompt the user for input.