pub fn detect_context(target: Option<&str>, repo_root: &Path) -> TemplateContextExpand description
Detect context from target path and git repository (legacy, ignores warnings)
pub fn detect_context(target: Option<&str>, repo_root: &Path) -> TemplateContextDetect context from target path and git repository (legacy, ignores warnings)