is_read_only

Function is_read_only 

pub fn is_read_only(name: &str) -> bool
Returns true for tools that are pure reads with no side-effects. These can safely be executed in parallel when the LLM issues several at once.