pub fn tool_defs(search_enabled: bool, pr_enabled: bool) -> Vec<ToolDef>
Return the tool definitions to send to the LLM. search_web is gated on a search key being present. create_pr / get_ci_status are gated on pr_enabled.
search_web
create_pr
get_ci_status
pr_enabled