hover_grep

Function hover_grep 

pub fn hover_grep(workspace: &Path, file: &Path, line: u32, col: u32) -> String
Show type / doc context for the symbol at file:line:col (grep-based).

Returns the target line plus two lines of surrounding context, and a grep search for the nearest definition of the same identifier.