pub fn init_worker_for_parallel(config: &WebhookConfig, worker_count: u8)Expand description
Initialize the webhook dispatcher with capacity scaled for parallel execution.
pub fn init_worker_for_parallel(config: &WebhookConfig, worker_count: u8)Initialize the webhook dispatcher with capacity scaled for parallel execution.