pub struct RunOneArgs {
pub debug: bool,
pub id: Option<String>,
pub non_interactive: bool,
pub dry_run: bool,
pub parallel_worker: bool,
pub coordinator_queue_path: Option<PathBuf>,
pub coordinator_done_path: Option<PathBuf>,
pub parallel_target_branch: Option<String>,
pub agent: RunAgentArgs,
}Fields
debug: boolCapture raw supervisor + runner output to .ralph/logs/debug.log.
id: Option<String>Run a specific task by ID.
non_interactive: boolSkip interactive prompts (for CI/non-interactive environments).
dry_run: boolSelect a task and print why it would (or would not) run. Does not invoke any runner and does not write queue/done.
parallel_worker: boolInternal: run as a parallel worker (skips queue lock, allows upstream creation).
coordinator_queue_path: Option<PathBuf>Internal: queue file path for the parallel worker workspace checkout.
coordinator_done_path: Option<PathBuf>Internal: done file path for the parallel worker workspace checkout.
parallel_target_branch: Option<String>Internal: explicit coordinator target branch for parallel integration.
agent: RunAgentArgsTrait Implementations
Sourceimpl Args for RunOneArgs
impl Args for RunOneArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl FromArgMatches for RunOneArgs
impl FromArgMatches for RunOneArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Auto Trait Implementations
impl Freeze for RunOneArgs
impl RefUnwindSafe for RunOneArgs
impl Send for RunOneArgs
impl Sync for RunOneArgs
impl Unpin for RunOneArgs
impl UnsafeUnpin for RunOneArgs
impl UnwindSafe for RunOneArgs