pub fn create_ralph_temp_file(label: &str) -> Result<NamedTempFile>Expand description
Creates a NamedTempFile in the ralph temp directory with the ralph_ prefix. This ensures the file will be caught by cleanup_default_temp_dirs().
pub fn create_ralph_temp_file(label: &str) -> Result<NamedTempFile>Creates a NamedTempFile in the ralph temp directory with the ralph_ prefix. This ensures the file will be caught by cleanup_default_temp_dirs().