commit_all

Function commit_all 

pub fn commit_all(repo_root: &Path, message: &str) -> Result<(), GitError>
Create a commit with all changes.

Stages everything and creates a single commit with the given message. Returns an error if the message is empty or there are no changes to commit.