push_head_to_branch

Function push_head_to_branch 

pub fn push_head_to_branch(
    repo_root: &Path,
    remote: &str,
    branch: &str,
) -> Result<(), GitError>
Push HEAD to a specific branch on a remote.

This pushes HEAD to the specified branch on the remote, creating the branch if needed. Used in direct-push parallel mode to push directly to the base branch.